export const description =
  '在此页面中，我们将深入探讨如何通过不同的接口实现符合预期的交互。'

## CORS

每次蝙蝠侠尝试访问 API 时，都会遇到 CORS 错误，这让他苦不堪言。

## 扩展应用程序

<Row>
<Col>
You can allow CORS for your application by adding the following code:
</Col>
  <Col>

    <CodeGroup title="Request" tag="GET" label="/hello_world">

    ```python {{ title: 'untyped' }}
      from robyn import Robyn, ALLOW_CORS

      app = Robyn(__file__)
      ALLOW_CORS(app, origins = ["http://localhost:<PORT>/"])
    ```

    ```python {{ title: 'typed' }}
      from robyn import Robyn, ALLOW_CORS

      app = Robyn(__file__)
      ALLOW_CORS(app, origins = ["http://localhost:<PORT>/"])
    ```

    </CodeGroup>

  </Col>
</Row>

---

## 下一步

修复了 CORS 问题后，蝙蝠侠感到非常满意，现在他希望了解如何在服务器中集成小型前端页面。

于是，Robyn 向他介绍了模板系统，以及如何使用模板来渲染 HTML 页面。

- [模板系统](/documentation/zh/api_reference/templating)
